@@ -1,4 +1,5 @@
 from serverless.service.plugins.generic import Generic
+import troposphere.ssm as ssm
 
 
 class DomainManager(Generic):
@@ -8,10 +9,12 @@ class DomainManager(Generic):
 
     yaml_tag = "!DomainManagerPlugin"
 
-    def __init__(self, domain, api="rest", stage="${sls:stage}", base_path=None, create_route_53_record=False):
+    def __init__(self, domain="api", api="rest", stage="${sls:stage}", base_path="", create_route_53_record=False, **kwargs):
         super().__init__("serverless-domain-manager")
+
+        kwargs.setdefault("domainName", f"{api}.{domain}")
         self[api] = dict(
-            domainName=f"{api}.{domain}", stage=stage, basePath=base_path, createRoute53Record=create_route_53_record
+            stage=stage, basePath=base_path, createRoute53Record=create_route_53_record, **kwargs
         )
 
     def enable(self, service):
@@ -19,3 +22,8 @@ class DomainManager(Generic):
         export.pop("name", None)
 
         service.custom.customDomain = export
+        param = service.resources.parameter(
+            "RESTApiId",
+            "api-id",
+            {"Fn::GetAtt": ["ApiGatewayRestApi", "RootResourceId"]}
+        )
